JsDoc Reference - dom.clone

Generated by JsDoc Toolkit 2.4.0 on Wed Dec 15 2010 21:56:33 GMT-0000 (GMT)
HTML template: Codeview

# Namespace dom.clone

Cloned table nodes
Defined in: FixedColumns.js.

Namespace Summary
Constructor Attributes | Constructor Name and Description
--- | ---
| dom.clone

Field Summary
Field Attributes | Field Name and Description
--- | ---
<static> | dom.clone.body Cloned body table
<static> | dom.clone.footer Cloned footer table
<static> | dom.clone.header Cloned header table

Namespace Detail
dom.clone
Field Detail
<static> {node} dom.clone.body
Cloned body table

Default Value:
  null

<static> {node} dom.clone.footer
Cloned footer table

Default Value:
  null

<static> {node} dom.clone.header
Cloned header table

Default Value:
  null